==> dhcp-agent-0.40.tar.gz: dhcp-agent-0.40/src/dhcp-server.h <==
/* $Header: /cvsroot/dhcp-agent/dhcp-agent/src/dhcp-server.h,v 1.2 2003/07/05 19:17:48 actmodern Exp $
 * 
 * Copyright 2002 Thamer Alharbash <tmh@whitefang.com>
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in
 * the documentation and/or other materials provided with the
 * distribution.
 * 3. The names of the authors may not be used to endorse or promote
 * products derived from this software without specific prior
 * written permission.
 * 
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

#ifndef DHCP_SERVER_H
#define DHCP_SERVER_H

/* type definitions. */
typedef void (*server_command) (char *interface);

typedef struct {

    rawnet_t *rawnet;     /* raw network handle */
    char *interface_name; /* name of interface */

    server_conf_t *server_conf;  /* server configuration. */

} dhcp_server_control_t;

/* constants. */
enum command_codes { DO_VERSION = 0, DO_KILL, DO_STATUS, DO_SERVER };

/* prototypes. */

extern dhcp_server_control_t *dhcp_server_control_create(const char *interface);

#endif /* DHCP_SERVER_H */

==> dhcp-agent-0.41.tar.gz: dhcp-agent-0.41/src/dhcp-server.h <==
/* $Header: /cvsroot/dhcp-agent/dhcp-agent/src/dhcp-server.h,v 1.5 2003/07/15 10:57:55 actmodern Exp $
 * 
 * Copyright 2003 Thamer Alharbash <tmh@whitefang.com>
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in
 * the documentation and/or other materials provided with the
 * distribution.
 * 3. The names of the authors may not be used to endorse or promote
 * products derived from this software without specific prior
 * written permission.
 * 
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

#ifndef DHCP_SERVER_H
#define DHCP_SERVER_H

typedef struct {

    rawnet_t *rawnet;     /* raw network handle */
    char *interface; /* name of interface */

    server_conf_t *server_conf;  /* server configuration. */

} dhcp_server_control_t;

/* type definitions. */
typedef void (*server_command) (char *interface);
typedef int  (*server_state)   (dhcp_server_control_t *);

/* constants. */
enum command_codes { DO_VERSION = 0, DO_KILL, DO_STATUS, DO_SERVER, DO_CHECK_CONFIG };
enum server_states { STATE_LISTEN, STATE_SHUTDOWN = 0 };
enum server_events { SERVER_EVENT_DATA_WAITING = 0, SERVER_EVENT_LEASE_EXPIRE, SERVER_EVENT_ERROR };

/* prototypes. */

extern dhcp_server_control_t *dhcp_server_control_create(const char *interface);
extern void dhcp_server_control_destroy(dhcp_server_control_t *sc);

extern int server_shutdown(dhcp_server_control_t *sc);

#endif /* DHCP_SERVER_H */
